Summary: Execution Environment Service for the ARGUS framework
Name: ees
Version: 0.1.4
Release: 1%{?dist}
Vendor: Nikhef
License: ASL 2.0
Group: System Environment/Daemons
URL: http://wiki.nikhef.nl/grid/EES
Source0: http://software.nikhef.nl/security/%{name}/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: bison, flex
BuildRequires: xacml-devel
BuildRequires: gsoap-devel
Requires: logrotate
Requires(post): chkconfig
Requires(preun): initscripts, chkconfig
Requires(postun): initscripts

%description

The EES is a service that can procure execution environments on Grid
sites.  These execution environments can be as simple as an existing
Unix user account to which the supplied user credentials are mapped
or as complex as deploying full virtual machines for a user. 

The role of the EES is to ensure that an appropriate site-specific
execution environment is procured based on the site-agnostic
obligations and attributes it receives as input in the form of
SAML2-XACML2 requests. It responds to requests from the Policy
Decision Point (PDP), but can also act as a standalone service.

%package devel
Summary: Execution Environment Service development files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel

This package contains the header files and development libraries
of the ees package.

%prep
%setup -q

%build

%configure --disable-static --disable-rpath

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'
# Create log directory such that we can give it the right permissions
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/log/ees

%clean
rm -rf $RPM_BUILD_ROOT

# Add the ees user (see http://fedoraproject.org/wiki/Packaging:UsersAndGroups)
%pre
getent group ees >/dev/null || groupadd -r ees
getent passwd ees >/dev/null || \
    useradd -r -g ees -d / -s /sbin/nologin \
    -c "ees user account to be used with %{_sbindir}/ees" ees
exit 0

%post
/sbin/ldconfig
/sbin/chkconfig --add ees

%preun
if [ $1 -eq 0 ] ; then
    /sbin/service ees stop >/dev/null 2>&1
    /sbin/chkconfig --del ees
fi

%postun
/sbin/ldconfig
if [ "$1" -ge "1" ] ; then
    /sbin/service ees condrestart >/dev/null 2>&1 || :
fi



%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README
%doc setup/gridmapfile.example
# Create ees config file owned by ees group such that ees can read it. Others
# should not be able as it might contain passwords.
%attr(640, root, ees) %config(noreplace) %{_sysconfdir}/ees.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/ees
%{_sysconfdir}/init.d/ees
%{_libdir}/*.so.*
# Next two lines are the basic EES plugins
%{_libdir}/ees/*.mod
%{_libdir}/ees/*.so
%{_sbindir}/ees
%{_datadir}/man/man1/ees.1*
%{_datadir}/man/man5/ees.conf.5*
# Create log directory owned and writeable by ees group, such that ees can
# create logfile.
%attr(770, root, ees) %{_localstatedir}/log/ees

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so

%changelog
* Fri Oct 25 2012 Mischa Salle <msalle@nikhef.nl> 0.1.4-1
- Only add non-plugin .so files to devel package.
- Add logrotate script, including requires.
- Add appropriate post, preun and postun section to enable and disable the
  service.
- Do not install the INSTALL file.
- Update URL.
- Update version.

* Mon Mar 26 2012 Mischa Salle <msalle@nikhef.nl> 0.1.3-1
- Create config file with specific permissions and ownership 
- Add noreplace flag to config file
- Create log directory %%{_localstatedir}/ees
- Add EES user and group
- Put Build dependency on xacml-devel instead of saml2-xacml2-c-lib-devel
- Bumped version

* Thu Mar  1 2012 Mischa Salle <msalle@nikhef.nl> 0.1.2-1
- Bumped version

* Mon Jan 30 2012 Mischa Salle <msalle@nikhef.nl> 0.1.1-1
- Bumped version

* Fri Dec 16 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.1.0
- Update build dependency on xacml

* Fri Dec 16 2011 Mischa Salle <msalle@nikhef.nl> 0.1.0-1
- Bumped version

* Tue Aug 23 2011 Mischa Salle <msalle@nikhef.nl> 0.0.10-4
- removed commented-out files
- Bumped version

* Tue Aug 23 2011 Mischa Salle <msalle@nikhef.nl> 0.0.10-3
- no longer needed to move init.d script
- Bumped version

* Mon Mar  7 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.3-1
- Bumped version
- disable rpath

* Fri Mar  4 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.2-2
- fixed license string
- disable static libraries
- added post(-un) scripts

* Thu Mar  3 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.2-1
- Bumped version number

* Fri Feb 25 2011 Dennis van Dok <dennisvd@nikhef.nl> 
- Initial build.


